aboutsummaryrefslogtreecommitdiff
path: root/riscv/processor.h
diff options
context:
space:
mode:
authorAndrew Waterman <waterman@s141.Millennium.Berkeley.EDU>2011-01-18 17:51:52 -0800
committerAndrew Waterman <waterman@s141.Millennium.Berkeley.EDU>2011-01-18 17:51:52 -0800
commit21ce327f5d60d6805b5d9328b68f7ad2c261a859 (patch)
tree22ee7ac3dfb4d00662ff6f0d1f057481efc67772 /riscv/processor.h
parent5ddec097b858aafe783eb3aff551d00e9c8c8a37 (diff)
downloadspike-21ce327f5d60d6805b5d9328b68f7ad2c261a859.zip
spike-21ce327f5d60d6805b5d9328b68f7ad2c261a859.tar.gz
spike-21ce327f5d60d6805b5d9328b68f7ad2c261a859.tar.bz2
[opcodes, sim, xcc] made *w insns illegal in RV32
now generic variants behave differently in RV32 and RV64.
Diffstat (limited to 'riscv/processor.h')
-rw-r--r--riscv/processor.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/riscv/processor.h b/riscv/processor.h
index 9ccfbb4..b548038 100644
--- a/riscv/processor.h
+++ b/riscv/processor.h
@@ -19,8 +19,8 @@ private:
sim_t* sim;
// architected state
- reg_t R[NGPR];
- freg_t FR[NFPR];
+ reg_t XPR[NXPR];
+ freg_t FPR[NFPR];
// privileged control registers
reg_t pc;
@@ -41,8 +41,8 @@ private:
// unprivileged control registers
uint32_t fsr;
- // 32-bit or 64-bit mode (redundant with sr)
- int gprlen;
+ // # of bits in an XPR (32 or 64). (redundant with sr)
+ int xprlen;
// shared memory
mmu_t mmu;